@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2006-2007 Imendio AB.
- * Copyright (C) 2007 Collabora Ltd.
+ * Copyright (C) 2007-2008 Collabora Ltd.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -38,10 +38,10 @@ G_BEGIN_DECLS
 
 typedef struct _EmpathyAvatarChooser        EmpathyAvatarChooser;
 typedef struct _EmpathyAvatarChooserClass   EmpathyAvatarChooserClass;
-typedef struct _EmpathyAvatarChooserPrivate EmpathyAvatarChooserPrivate;
 
 struct _EmpathyAvatarChooser {
 	GtkButton parent;
+	gpointer priv;
 };
 
 struct _EmpathyAvatarChooserClass {
