@@ -33,16 +33,13 @@
 
 #include "empathy-contact.h"
 #include "empathy-utils.h"
-#include "empathy-debug.h"
 #include "empathy-enum-types.h"
 
-#define DEBUG_DOMAIN "Contact"
+#define DEBUG_FLAG EMPATHY_DEBUG_CONTACT
+#include "empathy-debug.h"
 
-#define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), EMPATHY_TYPE_CONTACT, EmpathyContactPriv))
-
-typedef struct _EmpathyContactPriv EmpathyContactPriv;
-
-struct _EmpathyContactPriv {
+#define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyContact)
+typedef struct {
 	gchar              *id;
 	gchar              *name;
 	EmpathyAvatar      *avatar;
@@ -52,10 +49,10 @@ struct _EmpathyContactPriv {
 	guint               handle;
 	EmpathyCapabilities capabilities;
 	gboolean            is_user;
-};
+	guint               hash;
+	EmpathyContactReady ready;
+} EmpathyContactPriv;
 
-static void empathy_contact_class_init (EmpathyContactClass *class);
-static void empathy_contact_init       (EmpathyContact      *contact);
 static void contact_finalize           (GObject             *object);
 static void contact_get_property       (GObject             *object,
 				        guint                param_id,
@@ -78,7 +75,8 @@ enum {
 	PROP_PRESENCE_MESSAGE,
 	PROP_HANDLE,
 	PROP_CAPABILITIES,
-	PROP_IS_USER
+	PROP_IS_USER,
+	PROP_READY
 };
 
 static void
@@ -168,12 +166,25 @@ empathy_contact_class_init (EmpathyContactClass *class)
 							       FALSE,
 							       G_PARAM_READWRITE));
 
+	g_object_class_install_property (object_class,
+					 PROP_READY,
+					 g_param_spec_flags ("ready",
+							     "Contact ready flags",
+							     "Flags for ready properties",
+							     EMPATHY_TYPE_CONTACT_READY,
+							     EMPATHY_CONTACT_READY_NONE,
+							     G_PARAM_READABLE));
+
 	g_type_class_add_private (object_class, sizeof (EmpathyContactPriv));
 }
 
 static void
 empathy_contact_init (EmpathyContact *contact)
 {
+	EmpathyContactPriv *priv = G_TYPE_INSTANCE_GET_PRIVATE (contact,
+		EMPATHY_TYPE_CONTACT, EmpathyContactPriv);
+
+	contact->priv = priv;
 }
 
 static void
@@ -183,7 +194,7 @@ contact_finalize (GObject *object)
 
 	priv = GET_PRIV (object);
 
-	empathy_debug (DEBUG_DOMAIN, "finalize: %p", object);
+	DEBUG ("finalize: %p", object);
 
 	g_free (priv->name);
 	g_free (priv->id);
@@ -212,8 +223,7 @@ contact_get_property (GObject    *object,
 
 	switch (param_id) {
 	case PROP_ID:
-		g_value_set_string (value,
-				    empathy_contact_get_id (EMPATHY_CONTACT (object)));
+		g_value_set_string (value, priv->id);
 		break;
 	case PROP_NAME:
 		g_value_set_string (value,
@@ -240,6 +250,9 @@ contact_get_property (GObject    *object,
 	case PROP_IS_USER:
 		g_value_set_boolean (value, priv->is_user);
 		break;
+	case PROP_READY:
+		g_value_set_flags (value, priv->ready);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 		break;
@@ -299,6 +312,18 @@ contact_set_property (GObject      *object,
 	};
 }
 
+static void
+contact_set_ready_flag (EmpathyContact      *contact,
+			EmpathyContactReady  flag)
+{
+	EmpathyContactPriv *priv = GET_PRIV (contact);
+
+	if (!(priv->ready & flag)) {
+		priv->ready |= flag;
+		g_object_notify (G_OBJECT (contact), "ready");
+	}
+}
+
 EmpathyContact *
 empathy_contact_new (McAccount *account)
 {
@@ -324,15 +349,11 @@ empathy_contact_get_id (EmpathyContact *contact)
 {
 	EmpathyContactPriv *priv;
 
-	g_return_val_if_fail (EMPATHY_IS_CONTACT (contact), "");
+	g_return_val_if_fail (EMPATHY_IS_CONTACT (contact), NULL);
 
 	priv = GET_PRIV (contact);
 
-	if (priv->id) {
-		return priv->id;
-	}
-
-	return "";
+	return priv->id;
 }
 
 void
@@ -346,14 +367,21 @@ empathy_contact_set_id (EmpathyContact *contact,
 
 	priv = GET_PRIV (contact);
 
-	if (priv->id && strcmp (id, priv->id) == 0) {
-		return;
+	/* We temporally ref the contact because it could be destroyed
+	 * during the signal emition */
+	g_object_ref (contact);
+	contact_set_ready_flag (contact, EMPATHY_CONTACT_READY_ID);
+	if (tp_strdiff (id, priv->id)) {
+		g_free (priv->id);
+		priv->id = g_strdup (id);
+
+		g_object_notify (G_OBJECT (contact), "id");
+		if (G_STR_EMPTY (priv->name)) {
+			g_object_notify (G_OBJECT (contact), "name");
+		}
 	}
 
-	g_free (priv->id);
-	priv->id = g_strdup (id);
-
-	g_object_notify (G_OBJECT (contact), "id");
+	g_object_unref (contact);
 }
 
 const gchar *
@@ -361,7 +389,7 @@ empathy_contact_get_name (EmpathyContact *contact)
 {
 	EmpathyContactPriv *priv;
 
-	g_return_val_if_fail (EMPATHY_IS_CONTACT (contact), "");
+	g_return_val_if_fail (EMPATHY_IS_CONTACT (contact), NULL);
 
 	priv = GET_PRIV (contact);
 
@@ -379,18 +407,17 @@ empathy_contact_set_name (EmpathyContact *contact,
 	EmpathyContactPriv *priv;
 
 	g_return_if_fail (EMPATHY_IS_CONTACT (contact));
-	g_return_if_fail (name != NULL);
 
 	priv = GET_PRIV (contact);
 
-	if (priv->name && strcmp (name, priv->name) == 0) {
-		return;
+	g_object_ref (contact);
+	contact_set_ready_flag (contact, EMPATHY_CONTACT_READY_NAME);
+	if (tp_strdiff (name, priv->name)) {
+		g_free (priv->name);
+		priv->name = g_strdup (name);
+		g_object_notify (G_OBJECT (contact), "name");
 	}
-
-	g_free (priv->name);
-	priv->name = g_strdup (name);
-
-	g_object_notify (G_OBJECT (contact), "name");
+	g_object_unref (contact);
 }
 
 EmpathyAvatar *
@@ -541,7 +568,7 @@ empathy_contact_get_handle (EmpathyContact *contact)
 
 void
 empathy_contact_set_handle (EmpathyContact *contact,
-			   guint          handle)
+			    guint           handle)
 {
 	EmpathyContactPriv *priv;
 
@@ -549,13 +576,13 @@ empathy_contact_set_handle (EmpathyContact *contact,
 
 	priv = GET_PRIV (contact);
 
-	if (priv->handle == handle) {
-		return;
+	g_object_ref (contact);
+	contact_set_ready_flag (contact, EMPATHY_CONTACT_READY_HANDLE);
+	if (handle != priv->handle) {
+		priv->handle = handle;
+		g_object_notify (G_OBJECT (contact), "handle");
 	}
-
-	priv->handle = handle;
-
-	g_object_notify (G_OBJECT (contact), "handle");
+	g_object_unref (contact);
 }
 
 EmpathyCapabilities
@@ -661,6 +688,18 @@ empathy_contact_can_voip (EmpathyContact *contact)
 				     EMPATHY_CAPABILITIES_VIDEO);
 }
 
+EmpathyContactReady
+empathy_contact_get_ready (EmpathyContact *contact)
+{
+	EmpathyContactPriv *priv;
+
+	g_return_val_if_fail (EMPATHY_IS_CONTACT (contact), FALSE);
+
+	priv = GET_PRIV (contact);
+
+	return priv->ready;
+}
+
 gboolean
 empathy_contact_equal (gconstpointer v1,
 		      gconstpointer v2)
@@ -686,15 +725,37 @@ guint
 empathy_contact_hash (gconstpointer key)
 {
 	EmpathyContactPriv *priv;
-	guint              hash;
 
 	g_return_val_if_fail (EMPATHY_IS_CONTACT (key), +1);
 
 	priv = GET_PRIV (EMPATHY_CONTACT (key));
 
-	hash = empathy_account_hash (empathy_contact_get_account (EMPATHY_CONTACT (key)));
-	hash += g_str_hash (empathy_contact_get_id (EMPATHY_CONTACT (key)));
+	if (priv->hash == 0) {
+		priv->hash = empathy_account_hash (priv->account) + g_str_hash (priv->id);
+	}
 
-	return hash;
+	return priv->hash;
+}
+
+static gboolean
+contact_is_ready_func (GObject  *contact,
+		       gpointer  user_data)
+{
+	EmpathyContactPriv *priv = GET_PRIV (contact);
+	EmpathyContactReady ready;
+
+	ready = GPOINTER_TO_UINT (user_data);
+
+	return (priv->ready & ready) == ready;
+}
+
+void
+empathy_contact_run_until_ready (EmpathyContact      *contact,
+				 EmpathyContactReady  ready,
+				 GMainLoop          **loop)
+{
+	empathy_run_until_ready_full (contact, "notify::ready",
+				      contact_is_ready_func, GUINT_TO_POINTER (ready),
+				      loop);
 }
 
