@@ -31,22 +31,17 @@
 #include "empathy-tp-roomlist.h"
 #include "empathy-chatroom.h"
 #include "empathy-utils.h"
+
+#define DEBUG_FLAG EMPATHY_DEBUG_TP
 #include "empathy-debug.h"
 
-#define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), \
-		       EMPATHY_TYPE_TP_ROOMLIST, EmpathyTpRoomlistPriv))
-
-#define DEBUG_DOMAIN "TpRoomlist"
-
-struct _EmpathyTpRoomlistPriv {
+#define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyTpRoomlist)
+typedef struct {
 	TpConnection *connection;
 	TpChannel    *channel;
 	McAccount    *account;
 	gboolean      is_listing;
-};
-
-static void empathy_tp_roomlist_class_init (EmpathyTpRoomlistClass *klass);
-static void empathy_tp_roomlist_init       (EmpathyTpRoomlist      *chat);
+} EmpathyTpRoomlistPriv;
 
 enum {
 	NEW_ROOM,
@@ -72,7 +67,7 @@ tp_roomlist_listing_cb (TpChannel *channel,
 {
 	EmpathyTpRoomlistPriv *priv = GET_PRIV (list);
 
-	empathy_debug (DEBUG_DOMAIN, "Listing: %s", listing ? "Yes" : "No");
+	DEBUG ("Listing: %s", listing ? "Yes" : "No");
 	priv->is_listing = listing;
 	g_object_notify (list, "is-listing");
 }
@@ -139,8 +134,7 @@ tp_roomlist_get_listing_rooms_cb (TpChannel    *channel,
 	EmpathyTpRoomlistPriv *priv = GET_PRIV (list);
 
 	if (error) {
-		empathy_debug (DEBUG_DOMAIN, "Error geting listing rooms: %s",
-			       error->message);
+		DEBUG ("Error geting listing rooms: %s", error->message);
 		return;
 	}
 
@@ -155,7 +149,7 @@ tp_roomlist_invalidated_cb (TpChannel         *channel,
 			    gchar             *message,
 			    EmpathyTpRoomlist *list)
 {
-	empathy_debug (DEBUG_DOMAIN, "Channel invalidated: %s", message);
+	DEBUG ("Channel invalidated: %s", message);
 	g_signal_emit (list, signals[DESTROY], 0);
 }
 
@@ -169,8 +163,7 @@ tp_roomlist_request_channel_cb (TpConnection *connection,
 	EmpathyTpRoomlistPriv *priv = GET_PRIV (list);
 
 	if (error) {
-		empathy_debug (DEBUG_DOMAIN, "Error requesting channel: %s",
-			       error->message);
+		DEBUG ("Error requesting channel: %s", error->message);
 		return;
 	}
 
@@ -207,7 +200,7 @@ tp_roomlist_finalize (GObject *object)
 	EmpathyTpRoomlistPriv *priv = GET_PRIV (object);
 
 	if (priv->channel) {
-		empathy_debug (DEBUG_DOMAIN, "Closing channel...");
+		DEBUG ("Closing channel...");
 		g_signal_handlers_disconnect_by_func (priv->channel,
 						      tp_roomlist_invalidated_cb,
 						      object);
@@ -339,25 +332,32 @@ empathy_tp_roomlist_class_init (EmpathyTpRoomlistClass *klass)
 static void
 empathy_tp_roomlist_init (EmpathyTpRoomlist *list)
 {
+	EmpathyTpRoomlistPriv *priv = G_TYPE_INSTANCE_GET_PRIVATE (list,
+		EMPATHY_TYPE_TP_ROOMLIST, EmpathyTpRoomlistPriv);
+
+	list->priv = priv;
 }
 
 EmpathyTpRoomlist *
 empathy_tp_roomlist_new (McAccount *account)
 {
-	MissionControl *mc;
-	TpConnection   *connection;
+	EmpathyTpRoomlist *list;
+	MissionControl    *mc;
+	TpConnection      *connection;
 
 	g_return_val_if_fail (MC_IS_ACCOUNT (account), NULL);
 
 	mc = empathy_mission_control_new ();
 	connection = mission_control_get_tpconnection (mc, account, NULL);
 
-	return g_object_new (EMPATHY_TYPE_TP_ROOMLIST,
+	list = g_object_new (EMPATHY_TYPE_TP_ROOMLIST,
 			     "connection", connection,
 			     NULL);
 
 	g_object_unref (mc);
 	g_object_unref (connection);
+
+	return list;
 }
 
 gboolean
@@ -376,6 +376,7 @@ empathy_tp_roomlist_start (EmpathyTpRoomlist *list)
 	EmpathyTpRoomlistPriv *priv = GET_PRIV (list);
 
 	g_return_if_fail (EMPATHY_IS_TP_ROOMLIST (list));
+	g_return_if_fail (TP_IS_CHANNEL (priv->channel));
 
 	tp_cli_channel_type_room_list_call_list_rooms (priv->channel, -1,
 						       NULL, NULL, NULL,
@@ -388,6 +389,7 @@ empathy_tp_roomlist_stop (EmpathyTpRoomlist *list)
 	EmpathyTpRoomlistPriv *priv = GET_PRIV (list);
 
 	g_return_if_fail (EMPATHY_IS_TP_ROOMLIST (list));
+	g_return_if_fail (TP_IS_CHANNEL (priv->channel));
 
 	tp_cli_channel_type_room_list_call_stop_listing (priv->channel, -1,
 							 NULL, NULL, NULL,
